# REFERENCE: proxy_default.xml
__( q{General} );
# REFERENCE: proxy_default.xml
__( q{Client Reports} );
# REFERENCE: proxy_default.xml
__( q{Users Reports} );
# REFERENCE: proxy_default.xml
__( q{Cache Reports} );
# REFERENCE: proxy_default.xml
__( q{Denied Sites Reports} );
# REFERENCE: schema:proxy
__( q{DLF Schema for Proxy superservice} );
# REFERENCE: schema:proxy
__( q{This DLF file is adequate to represent most common informations about web proxy events. It has the same information as found in most proxy-like servers log files.   </para> <para>This schema is adequate for proxy servers beyond web proxys servers. It can be used for socks and other types of connection-level proxies. </para>  <para>The DLF schema was designed by studying the WebTrends Enhanced Log Format, squid log files and thinking about SOCKS type of server. } );
# REFERENCE: schema:proxy
__( q{Timestamp} );
# REFERENCE: schema:proxy
__( q{The time at which the request was initiated.} );
# REFERENCE: schema:proxy
__( q{Client IP} );
# REFERENCE: schema:proxy
__( q{The IP address of the client.} );
# REFERENCE: schema:proxy
__( q{Client Host} );
# REFERENCE: schema:proxy
__( q{The hostname of the client. } );
# REFERENCE: schema:proxy
__( q{User} );
# REFERENCE: schema:proxy
__( q{If the client was authenticated, this field should contains the authenticated username.} );
# REFERENCE: schema:proxy
__( q{Duration} );
# REFERENCE: schema:proxy
__( q{The time taken by the connection.} );
# REFERENCE: schema:proxy
__( q{Cache Result} );
# REFERENCE: schema:proxy
__( q{Result code for the cache TCP_MISS, TCP_HIT, etc.  List is available on Squid page, and in squid_access2dlf(1). All DLF converter should map their native value to the squid's one which is very complete and exhaustive. } );
# REFERENCE: schema:proxy
__( q{Result} );
# REFERENCE: schema:proxy
__( q{HTTP result of the request. e.g. 200 or 404.} );
# REFERENCE: schema:proxy
__( q{Protocol} );
# REFERENCE: schema:proxy
__( q{The protocol of the proxied request: ftp, http, https, telnet, etc.} );
# REFERENCE: schema:proxy
__( q{Transport} );
# REFERENCE: schema:proxy
__( q{The protocol used between the client and the proxy server. This is probably TCP, but can be UDP in some case (like SOCKS or ICP). } );
# REFERENCE: schema:proxy
__( q{Destination IP} );
# REFERENCE: schema:proxy
__( q{The ip address of the destination.} );
# REFERENCE: schema:proxy
__( q{Destination Host} );
# REFERENCE: schema:proxy
__( q{The hostname of the destination. In the case of web proxy, that will be the website} );
# REFERENCE: schema:proxy
__( q{Destination Port} );
# REFERENCE: schema:proxy
__( q{Port of the destination used in IP session} );
# REFERENCE: schema:proxy
__( q{Operation} );
# REFERENCE: schema:proxy
__( q{This field should only be defined in the case of web proxy requests. This should contains the HTTP method requested like <literal>GET</literal> or <literal>POST</literal>. } );
# REFERENCE: schema:proxy
__( q{URL} );
# REFERENCE: schema:proxy
__( q{This field should only be defined in the case of web proxy request. It should contains the URL requested on the remote server.} );
# REFERENCE: schema:proxy
__( q{Result Size} );
# REFERENCE: schema:proxy
__( q{The number of bytes transferred from proxy server to the client} );
# REFERENCE: schema:proxy
__( q{Result's Type} );
# REFERENCE: schema:proxy
__( q{This field should only be defined for web proxy servers, it should contains the MIME type of the HTTP request's result (e.g. text/html or image/jpeg).} );
# REFERENCE: schema:proxy
__( q{Rule} );
# REFERENCE: schema:proxy
__( q{This field contains the configuration rule's name that was used to accept or deny to request. } );
# REFERENCE: schema:proxy
__( q{User Agent} );
# REFERENCE: schema:proxy
__( q{The useragent used by the client. E.g. 'Mozilla/4.0 (compatible; MSIE 5.0; Win32)' or 'Outlook Express/5.0 (MSIE 5.0; Windows 98; DigExt)'} );
# REFERENCE: schema:proxy
__( q{Result Source Type} );
# REFERENCE: schema:proxy
__( q{Code qualifying the next two fields. (i.e. NONE, DIRECT, PARENT_HIT, etc.) All DLF converter should map their native value to the squid's one which is very complete and exhaustive.    } );
# REFERENCE: schema:proxy
__( q{Result IP} );
# REFERENCE: schema:proxy
__( q{The IP address of the server which handled the request, i.e. destination or other cache} );
# REFERENCE: schema:proxy
__( q{Result Host} );
# REFERENCE: schema:proxy
__( q{The hostname of the server that handled the request and gave the result.} );
# REFERENCE: schema:proxy
__( q{Result Port} );
# REFERENCE: schema:proxy
__( q{Port on referring host used in IP session.} );
# REFERENCE: schema:proxy
__( q{Category Action} );
# REFERENCE: schema:proxy
__( q{This field contains either the value <constant>block</constant> or <constant>pass</constant>. It is used when access control is based on content filtering. } );
# REFERENCE: schema:proxy
__( q{Site Category} );
# REFERENCE: schema:proxy
__( q{If the proxy server is doing content analysis, this field should contains the category for the requested website. } );
# REFERENCE: schema:proxy
__( q{Site Level} );
# REFERENCE: schema:proxy
__( q{Level can be 1 or 2. 1 meaning "no no" categories. 2 meaning "family fun" categories. This was taken from the WELF specification. } );
# REFERENCE: schema:proxy
__( q{Page Category} );
# REFERENCE: schema:proxy
__( q{Like <structfield>cat_site</structfield>, but for the actual page.} );
# REFERENCE: schema:proxy
__( q{Page Level} );
# REFERENCE: schema:proxy
__( q{Like <structfield>catlevel_site</structfield>, but for the actual page.} );
# REFERENCE: report:proxy:bytes-by-cache_result
__( q{Bytes by Cache Result} );
# REFERENCE: report:proxy:bytes-by-cache_result
__( q{This report shows the number of bytes transferred for each cache result. This gives an idea of how effective is the cache. } );
# REFERENCE: report:proxy:bytes-by-cache_result
__( q{Bytes by Cache Result} );
# REFERENCE: report:proxy:bytes-by-cache_result
__( q{Bytes} );
# REFERENCE: report:proxy:bytes-by-cache_result
__( q{% Total} );
# REFERENCE: report:proxy:bytes-by-period
__( q{Bytes Transferred By Period Proxy Report} );
# REFERENCE: report:proxy:bytes-by-period
__( q{This report shows the number of bytes transferred by a user-configurable time period. } );
# REFERENCE: report:proxy:bytes-by-period
__( q{This parameter controls the time period which is use to aggregate the records. } );
# REFERENCE: report:proxy:bytes-by-period
__( q{Bytes Transferred by $period Period} );
# REFERENCE: report:proxy:bytes-by-period
__( q{Period} );
# REFERENCE: report:proxy:bytes-by-period
__( q{Bytes} );
# REFERENCE: report:proxy:bytes-by-period
__( q{% Total} );
# REFERENCE: report:proxy:bytes-by-result_src_code
__( q{Bytes by Object's Source} );
# REFERENCE: report:proxy:bytes-by-result_src_code
__( q{This report shows the number of bytes transferred from each source (Internet, Parent or sibling cache, etc.). This report is useful to analyze the performance of your array. } );
# REFERENCE: report:proxy:bytes-by-result_src_code
__( q{Bytes by Object's Source} );
# REFERENCE: report:proxy:bytes-by-result_src_code
__( q{Some explanation about common codes: <variablelist> <varlistentry> <term><constant>DIRECT</constant></term> <listitem> <para>This means that the object was fetched from the object's 	origin, i.e. usually the Internet's server. </para> </listitem> </varlistentry> <varlistentry> <term><constant>NONE</constant></term> <listitem> <para>This usually means that the object was returned from the local 	cache. </para> </listitem> </varlistentry> </variablelist> Other codes usually refers to the cache's hierarchy. } );
# REFERENCE: report:proxy:bytes-by-result_src_code
__( q{Bytes} );
# REFERENCE: report:proxy:bytes-by-result_src_code
__( q{% Total} );
# REFERENCE: report:proxy:bytes-by-timeslot
__( q{Bytes Transferred By Timeslot Proxy Report} );
# REFERENCE: report:proxy:bytes-by-timeslot
__( q{This report shows the number of bytes transferred by user-configurable timeslot (hours of the day, days of the week, etc.). This report is useful to spot the most used period of the day for example. } );
# REFERENCE: report:proxy:bytes-by-timeslot
__( q{This parameter controls the unit of time used to aggregate the records. } );
# REFERENCE: report:proxy:bytes-by-timeslot
__( q{Bytes Transferred by $timeslot Timeslot} );
# REFERENCE: report:proxy:bytes-by-timeslot
__( q{Timeslot} );
# REFERENCE: report:proxy:bytes-by-timeslot
__( q{Bytes} );
# REFERENCE: report:proxy:bytes-by-timeslot
__( q{% Total} );
# REFERENCE: report:proxy:requests-by-cache_result
__( q{Requests by Cache Result} );
# REFERENCE: report:proxy:requests-by-cache_result
__( q{This report shows the number of requests for each cache result. This gives an idea of how effective is the cache. } );
# REFERENCE: report:proxy:requests-by-cache_result
__( q{Requests by Cache Result} );
# REFERENCE: report:proxy:requests-by-cache_result
__( q{Requests} );
# REFERENCE: report:proxy:requests-by-cache_result
__( q{% Total} );
# REFERENCE: report:proxy:requests-by-period
__( q{Requests By Period Proxy Report} );
# REFERENCE: report:proxy:requests-by-period
__( q{This report shows the number of requests by a user-configurable time period. } );
# REFERENCE: report:proxy:requests-by-period
__( q{This parameter controls the time period which is use to aggregate the records. } );
# REFERENCE: report:proxy:requests-by-period
__( q{Requests Served by $period Period} );
# REFERENCE: report:proxy:requests-by-period
__( q{Period} );
# REFERENCE: report:proxy:requests-by-period
__( q{Requests} );
# REFERENCE: report:proxy:requests-by-period
__( q{% Total} );
# REFERENCE: report:proxy:requests-by-size
__( q{Requests By Size Proxy Report} );
# REFERENCE: report:proxy:requests-by-size
__( q{This report shows the number of requests by size. It shows the number of requests that were between 1k-5k, 5k-10k, etc.} );
# REFERENCE: report:proxy:requests-by-size
__( q{This parameter controls the size of the first range class. } );
# REFERENCE: report:proxy:requests-by-size
__( q{Requests by Request's Size} );
# REFERENCE: report:proxy:requests-by-size
__( q{Size} );
# REFERENCE: report:proxy:requests-by-size
__( q{Requests} );
# REFERENCE: report:proxy:requests-by-size
__( q{% Total} );
# REFERENCE: report:proxy:requests-by-time
__( q{Requests By Request's Time Proxy Report} );
# REFERENCE: report:proxy:requests-by-time
__( q{This report shows the number of requests by the time they took to process. It shows the number of requests that took between 0-1s, 1-2s, etc.} );
# REFERENCE: report:proxy:requests-by-time
__( q{This parameter controls the size of the first range class.} );
# REFERENCE: report:proxy:requests-by-time
__( q{Requests by Request's Time} );
# REFERENCE: report:proxy:requests-by-time
__( q{Time Taken} );
# REFERENCE: report:proxy:requests-by-time
__( q{Requests} );
# REFERENCE: report:proxy:requests-by-time
__( q{% Total} );
# REFERENCE: report:proxy:requests-by-timeslot
__( q{Number of Requests By Timeslot Proxy Report} );
# REFERENCE: report:proxy:requests-by-timeslot
__( q{This report shows the number of requests by user-configurable timeslot (hours of the day, days of the week, etc.). } );
# REFERENCE: report:proxy:requests-by-timeslot
__( q{This parameter controls the unit of time used to aggregate the records. } );
# REFERENCE: report:proxy:requests-by-timeslot
__( q{Requests by $timeslot Timeslot} );
# REFERENCE: report:proxy:requests-by-timeslot
__( q{Timeslot} );
# REFERENCE: report:proxy:requests-by-timeslot
__( q{Requests} );
# REFERENCE: report:proxy:requests-by-timeslot
__( q{% Total} );
# REFERENCE: report:proxy:top-clients-by-destinations
__( q{Top Clients by Destinations Proxy Report} );
# REFERENCE: report:proxy:top-clients-by-destinations
__( q{This report lists the most popular destinations along with the clients that accessed them. } );
# REFERENCE: report:proxy:top-clients-by-destinations
__( q{This parameter controls the number of clients for each destination to display in the report.} );
# REFERENCE: report:proxy:top-clients-by-destinations
__( q{This parameter controls the number of destinations to display in the report.} );
# REFERENCE: report:proxy:top-clients-by-destinations
__( q{Top Clients by Destinations, Top $dsts_to_show sites, Top $clients_to_show Clients} );
# REFERENCE: report:proxy:top-clients-by-destinations
__( q{Requests} );
# REFERENCE: report:proxy:top-clients-by-destinations
__( q{% Total} );
# REFERENCE: report:proxy:top-clients-by-destinations
__( q{% Destinations} );
# REFERENCE: report:proxy:top-destinations-by-bytes
__( q{Top Destinations by Bytes Downloaded} );
# REFERENCE: report:proxy:top-destinations-by-bytes
__( q{This report lists most popular sites by traffic} );
# REFERENCE: report:proxy:top-destinations-by-bytes
__( q{This parameter controls the number of destinations to display in the report.} );
# REFERENCE: report:proxy:top-destinations-by-bytes
__( q{Top Destination by Size, Top $dsts_to_show Sites} );
# REFERENCE: report:proxy:top-destinations-by-bytes
__( q{Bytes} );
# REFERENCE: report:proxy:top-destinations-by-bytes
__( q{% Total} );
# REFERENCE: report:proxy:top-destinations-by-clients
__( q{Top Destinations by Clients} );
# REFERENCE: report:proxy:top-destinations-by-clients
__( q{This report lists most popular sites by clients} );
# REFERENCE: report:proxy:top-destinations-by-clients
__( q{This parameter controls the number of clients to display in the report.} );
# REFERENCE: report:proxy:top-destinations-by-clients
__( q{This parameter controls the number of destinations to display in the report.} );
# REFERENCE: report:proxy:top-destinations-by-clients
__( q{Top Destinations by Client, Top $dsts_to_show Sites, Top $clients_to_show Clients} );
# REFERENCE: report:proxy:top-destinations-by-clients
__( q{Requests} );
# REFERENCE: report:proxy:top-destinations-by-clients
__( q{% Total} );
# REFERENCE: report:proxy:top-destinations-by-clients
__( q{% Client} );
# REFERENCE: report:proxy:top-destinations-by-users
__( q{Top Destinations by Users Proxy Report} );
# REFERENCE: report:proxy:top-destinations-by-users
__( q{This report lists most popular destinations, grouped by users} );
# REFERENCE: report:proxy:top-destinations-by-users
__( q{This parameter controls the number of destinations to display in the report for each user.} );
# REFERENCE: report:proxy:top-destinations-by-users
__( q{This parameter controls the number of users for each URL to display in the report.} );
# REFERENCE: report:proxy:top-destinations-by-users
__( q{Top Destinations by User, Top $users_to_show Users, Top $dsts_to_show sites} );
# REFERENCE: report:proxy:top-destinations-by-users
__( q{Requests} );
# REFERENCE: report:proxy:top-destinations-by-users
__( q{% Total} );
# REFERENCE: report:proxy:top-destinations-by-users
__( q{% Group} );
# REFERENCE: report:proxy:top-destinations
__( q{Top Destinations by Number of Requests} );
# REFERENCE: report:proxy:top-destinations
__( q{This report lists most popular sites} );
# REFERENCE: report:proxy:top-destinations
__( q{This parameter controls the number of destinations to display in the report.} );
# REFERENCE: report:proxy:top-destinations
__( q{Top Destination, Top $dsts_to_show Sites} );
# REFERENCE: report:proxy:top-destinations
__( q{Requests} );
# REFERENCE: report:proxy:top-destinations
__( q{% Total} );
# REFERENCE: report:proxy:top-types-by-bytes
__( q{Top MIME types by Transferred Size} );
# REFERENCE: report:proxy:top-types-by-bytes
__( q{This report lists the MIME types that resulted in the most traffic.} );
# REFERENCE: report:proxy:top-types-by-bytes
__( q{This parameter controls the number of MIME types to display in the report. } );
# REFERENCE: report:proxy:top-types-by-bytes
__( q{Top MIME Types by Bytes Transferred, Top $types_to_show} );
# REFERENCE: report:proxy:top-types-by-bytes
__( q{Bytes} );
# REFERENCE: report:proxy:top-types-by-bytes
__( q{% Total} );
# REFERENCE: report:proxy:top-urls-by-users
__( q{Top URLs by Users Proxy Report} );
# REFERENCE: report:proxy:top-urls-by-users
__( q{This report lists most popular URLs, grouped by users} );
# REFERENCE: report:proxy:top-urls-by-users
__( q{This parameter controls the number of URLs to display in the report.} );
# REFERENCE: report:proxy:top-urls-by-users
__( q{This parameter controls the number of users for each URL to display in the report.} );
# REFERENCE: report:proxy:top-urls-by-users
__( q{Top URLs by User, Top $users_to_show Users, Top $urls_to_show URLs} );
# REFERENCE: report:proxy:top-urls-by-users
__( q{Requests} );
# REFERENCE: report:proxy:top-urls-by-users
__( q{% Total} );
# REFERENCE: report:proxy:top-urls-by-users
__( q{% User} );
# REFERENCE: report:proxy:top-users-by-bytes
__( q{Top Users by Bytes Proxy Report} );
# REFERENCE: report:proxy:top-users-by-bytes
__( q{This report lists the users who downloaded biggest volume using the proxy} );
# REFERENCE: report:proxy:top-users-by-bytes
__( q{This parameter controls the number of users to display in the report.} );
# REFERENCE: report:proxy:top-users-by-bytes
__( q{Largest Volume Sent To User, Top $users_to_show} );
# REFERENCE: report:proxy:top-users-by-bytes
__( q{Volume is in bytes} );
# REFERENCE: report:proxy:top-users-by-bytes
__( q{Bytes} );
# REFERENCE: report:proxy:top-users-by-bytes
__( q{% Total} );
# REFERENCE: report:proxy:top-users-by-destinations
__( q{Top Users by Destinations Proxy Report} );
# REFERENCE: report:proxy:top-users-by-destinations
__( q{This report lists the most popular destinations along with the users that accessed them. } );
# REFERENCE: report:proxy:top-users-by-destinations
__( q{This parameter controls the number of destinations to display in the report. } );
# REFERENCE: report:proxy:top-users-by-destinations
__( q{This parameter controls the number of users for each destinations to display in the report.} );
# REFERENCE: report:proxy:top-users-by-destinations
__( q{Top Users by Destinations, Top $dsts_to_show sites, Top $users_to_show Users} );
# REFERENCE: report:proxy:top-users-by-destinations
__( q{Requests} );
# REFERENCE: report:proxy:top-users-by-destinations
__( q{% Total} );
# REFERENCE: report:proxy:top-users-by-destinations
__( q{% Dst} );
# REFERENCE: filter:proxy:select-cache_result
__( q{Select Cache Result Filter} );
# REFERENCE: filter:proxy:select-cache_result
__( q{This filter specification can be used to select only DLF records in the proxy superservice which have a particular <type>cache_result</type> value. For example, you could select only denied requests by using the value <constant>TCP_DENIED</constant>. } );
# REFERENCE: filter:proxy:select-cache_result
__( q{This parameter is a regular expression which will be used to select the codes you want. } );
# REFERENCE: filter:proxy:select-cache_result
__( q{$result requests} );
